@@ -3,7 +3,6 @@ from time import sleep
 
 import pyautogui
 import pynput
-import pyclip
 from pylayout import Layout
 from pynput.keyboard import Key
 from pynput.mouse import Button
@@ -19,20 +18,34 @@ logger.addHandler(stream)
 
 
 KEYS = {
+    "ctrl": Key.ctrl,
+    "ctrl_l": Key.ctrl_l,
+    "ctrl_r": Key.ctrl_r,
     "cmd": Key.cmd,
     "cmd_l": Key.cmd_l,
-    "ctrl": Key.ctrl,
     "alt": Key.alt,
-    "tab": Key.tab,
+    "alt_l": Key.alt_l,
+    "alt_r": Key.alt_l,
     "shift": Key.shift,
-    "backspace ": Key.backspace,
+    "shift_l": Key.shift_l,
+    "shift_r": Key.shift_r,
+    "caps_lock": Key.caps_lock,
+    "tab": Key.tab,
+    "esc": Key.esc,
     "space": Key.space,
     "enter": Key.enter,
-    "esc": Key.esc,
+    "print_screen": Key.print_screen,
+    "insert": Key.insert,
+    "delete": Key.delete,
+    "backspace": Key.backspace,
     "down": Key.down,
     "up": Key.up,
     "left": Key.left,
     "right": Key.right,
+    "home": Key.home,
+    "end": Key.end,
+    "page_up": Key.page_up,
+    "page_down": Key.page_down,
     "f1": Key.f1,
     "f2": Key.f2,
     "f3": Key.f3,
@@ -59,7 +72,6 @@ class KeyMouse:
         self._keyboard = pynput.keyboard.Controller()
         self._mouse = pynput.mouse.Controller()
         self.layout = Layout()
-        self.clipboard = pyclip
         # It is important to get layout as we need to change 0 thread language to 'us'
         cur_layout = self.layout.get()
         logger.debug(f"Layout: '{cur_layout}'")
@@ -174,19 +186,19 @@ class KeyMouse:
         """`Ctrl + C` hotkey"""
         sleep(delay)
         self.hotkey("ctrl", "c", interval=0.1)
-        logger.debug(f"Copy: '{pyclip.paste().decode()}'")
+        # logger.debug(f"Copy: '{pyclip.paste().decode()}'")
 
     def cut(self, delay=0.0):
         """`Ctrl + X` hotkey"""
         sleep(delay)
         self.hotkey("ctrl", "x", interval=0.1)
-        logger.debug(f"Copy: '{pyclip.paste().decode()}'")
+        # logger.debug(f"Copy: '{pyclip.paste().decode()}'")
 
     def paste(self, delay=0.0):
         """`Ctrl + V` hotkey"""
         sleep(delay)
         self.hotkey("ctrl", "v", interval=0.1)
-        logger.debug(f"Paste: '{pyclip.paste().decode()}'")
+        # logger.debug(f"Paste: '{pyclip.paste().decode()}'")
 
     def enter(self, delay=0.0):
         """`Enter` hotkey"""
